# Vicero - Reinforcement Learning Framework <img align="left" width="42" src="https://i.imgur.com/h6uqsjq.png">
This project is supposed to simplify the implementation of a wide range of techniques used for reinforcement learning. At the same time, the techniques themselves should be implemented cleanly and with precise yet easy to understand documentation.
# Setup guide for developers
To setup the project after cloning, run the following command in the project root. You might need to prefix it with sudo, if you don't have root privilegies already.
```
pip install -e .
```
This installs the current directory as if it was any python library, but with the -e (editable) flag it will keep the installation up-to-date with any edit to the source code.